@@ -71,16 +71,17 @@ WKEYMETH(_signal_signal)
 	   sv_2mortal(newSVpv(PL_sig_name[sg->signal],0)) : &PL_sv_undef);
     PUTBACK;
   } else {
-    int active = EvPOLLING(ev);
-    int sig = Perl_whichsig(SvPV(nval,PL_na));
-    /*warn("whichsig(%s) = %d", SvPV(nval,na), sig); /**/
-    if (sig == 0)
-      croak("Unrecognized signal '%s'", SvPV(nval,PL_na));
-    if (!PE_SIGVALID(sig))
-      croak("Signal '%s' cannot be caught", SvPV(nval,PL_na));
-    if (active) pe_watcher_off(ev);
-    sg->signal = sig;
-    if (active) pe_watcher_on(ev, 0);
+      STRLEN n_a;
+      int active = EvPOLLING(ev);
+      int sig = Perl_whichsig(SvPV(nval, n_a));
+      /*warn("whichsig(%s) = %d", SvPV(nval,na), sig); /**/
+      if (sig == 0)
+	  croak("Unrecognized signal '%s'", SvPV(nval, n_a));
+      if (!PE_SIGVALID(sig))
+	  croak("Signal '%s' cannot be caught", SvPV(nval, n_a));
+      if (active) pe_watcher_off(ev);
+      sg->signal = sig;
+      if (active) pe_watcher_on(ev, 0);
   }
 }
 
